<?xml version="1.0" encoding="utf-8"?>
<xsl:stylesheet version="1.0" xmlns="urn:hl7-org:v3" xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
  xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" 
  xmlns:sdtc="urn:hl7-org:sdtc" 
  xmlns:isc="http://extension-functions.intersystems.com"
  xmlns:exsl="http://exslt.org/common" 
  xmlns:set="http://exslt.org/sets" 
  xmlns:date="http://exslt.org/dates-and-times" 
  xmlns:str="http://exslt.org/strings"
  exclude-result-prefixes="isc xsi sdtc exsl set date str">
  
  <xsl:template match="Document" name="intTranslation-documentCategoryToLoinc">
    <xsl:param name="doc" select="." />
    <xsl:choose>
      <xsl:when test="DocumentType/Code/text() = 'PN'">
        <LOINC>11506-3</LOINC>
        <Display>Subsequent Evaluation Note</Display>
      </xsl:when>
      <xsl:when test="DocumentType/Code/text() = 'DS'">
        <LOINC>18842-5</LOINC>
        <Display>Discharge Summarization Note</Display>
      </xsl:when>
      <xsl:when test="DocumentType/Code/text() = 'CR'">
        <LOINC>11488-4</LOINC>
        <Display>Consultation Note</Display>
      </xsl:when>
      <xsl:when test="DocumentType/Code/text() = 'CP'">
        <LOINC>28570-0</LOINC>
        <Display>Procedure Note</Display>
      </xsl:when>
      <xsl:when test="DocumentType/Code/text() = 'SR'">
        <LOINC>29752-3</LOINC>
        <Display>Perioperative Records</Display>
      </xsl:when>
      <xsl:when test="DocumentType/Code/text() = 'RA'">
        <LOINC>18726-0</LOINC>
        <Display>Radiology Studies</Display>
      </xsl:when>
      <xsl:when test="DocumentType/Code/text() = 'LR'">
        <LOINC>27898-6</LOINC>
        <Display>Pathology Studies</Display>
      </xsl:when>
      <xsl:when test="DocumentType/Code/text() = 'C'">
        <LOINC>34904-3</LOINC>
        <Display>Progress Note - Mental Health</Display>
      </xsl:when>
      <xsl:when test="DocumentType/Code/text() = 'W'">
        <LOINC>71282-4</LOINC>
        <Display>Risk Assessment Document</Display>
      </xsl:when>
      <xsl:when test="DocumentType/Code/text() = 'A'">
        <LOINC>68629-5</LOINC>
        <Display>Allergy and Immunology Note</Display>
      </xsl:when>
      <xsl:when test="DocumentType/Code/text() = 'D'">
        <LOINC>42348-3</LOINC>
        <Display>Advance Directives</Display>
      </xsl:when>
      <xsl:when test="DocumentType/Code/text() = 'D'">
        <LOINC>42348-3</LOINC>
        <Display>Advance Directives</Display>
      </xsl:when>
      <xsl:when test="DocumentType/Code/text() = 'HP'">
        <LOINC>34117-2</LOINC>
        <Display>History and Physical Note</Display>
      </xsl:when>
      <xsl:when test="DocumentType/Code/text() = 'CM'">
        <LOINC>38954-4</LOINC>
        <Display>Compensation and Pension Exam</Display>
      </xsl:when>
      <xsl:otherwise>
        <LOINC>34109-9</LOINC>
        <Display>UNKNOWN NOTE</Display>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>
  
  <xsl:template name="intTranslation-FutureOrderTypeCode">
    <xsl:param name="doc" select="." />
    <xsl:choose>
      <xsl:when test="OrderCategory/Code/text() = 'AP'">
        Laboratory - Anatomic Pathology Order
      </xsl:when>
      <xsl:when test="OrderCategory/Code/text() = 'ANI'">
        Imaging - Angiography/Neuroradiology Order
      </xsl:when>
      <xsl:when test="OrderCategory/Code/text() = 'BB'">
        Laboratory - Blood Bank Order
      </xsl:when>
      <xsl:when test="OrderCategory/Code/text() = 'VBEC'">
        Laboratory - Blood Product Order
      </xsl:when>
      <xsl:when test="OrderCategory/Code/text() = 'CARD'">
        Imaging - Cardiology Study Order
      </xsl:when>
      <xsl:when test="OrderCategory/Code/text() = 'CPL'">
        Cardiopulmonary Order
      </xsl:when>
      <xsl:when test="OrderCategory/Code/text() = 'CH'">
        Laboratory - Chemistry Order
      </xsl:when>
      <xsl:when test="OrderCategory/Code/text() = 'C RX'">
        Pharmacy - Clinic Medication Order
      </xsl:when>
      <xsl:when test="OrderCategory/Code/text() = 'CI RX'">
        Pharmacy - Clinic Infusion Order
      </xsl:when>
      <xsl:when test="OrderCategory/Code/text() = 'CSLT'">
        Consult Order
      </xsl:when>
      <xsl:when test="OrderCategory/Code/text() = 'CT'">
        Imaging - CT Scan Order
      </xsl:when>
      <xsl:when test="OrderCategory/Code/text() = 'CY'">
        Laboratory - Cytology Order
      </xsl:when>
      <xsl:when test="OrderCategory/Code/text() = 'EM'">
        Laboratory - Electron Microscopy Order
      </xsl:when>
      <xsl:when test="OrderCategory/Code/text() = 'RAD'">
        Imaging - General Radiology Order
      </xsl:when>
      <xsl:when test="OrderCategory/Code/text() = 'HEMA'">
        Laboratory - Hematology Order
      </xsl:when>
      <xsl:when test="OrderCategory/Code/text() = 'MRI'">
        Imaging - Magnetic Resonance Imaging (MRI) Order
      </xsl:when>
      <xsl:when test="OrderCategory/Code/text() = 'MAM'">
        Imaging - Mammography Order
      </xsl:when>
      <xsl:when test="OrderCategory/Code/text() = 'MI'">
        Laboratory - Microbiology Order
      </xsl:when>
      <xsl:when test="OrderCategory/Code/text() = 'NM'">
        Imaging - Nuclear Medicine Order
      </xsl:when>
      <xsl:when test="OrderCategory/Code/text() = 'SUM'">
        Physical, Occupational or Respiratory Therapy (PT/OT/RT) Order
      </xsl:when>
      <xsl:when test="OrderCategory/Code/text() = 'PROC'">
        Procedure Order
      </xsl:when>
      <xsl:when test="OrderCategory/Code/text() = 'SURG'">
        Surgery Order
      </xsl:when>
      <xsl:when test="OrderCategory/Code/text() = 'SP'">
        Laboratory - Surgical Pathology
      </xsl:when>
      <xsl:when test="OrderCategory/Code/text() = 'US'">
        Imaging - Ultrasound Order
      </xsl:when>
      <xsl:when test="OrderCategory/Code/text() = 'VAS'">
        Imaging - Vascular Lab Order
      </xsl:when>
      <xsl:otherwise>
        
      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>
  <xsl:template match="Vaccination" mode="intTranslation-cvxgroup">
    <xsl:choose>
      <xsl:when test="OrderItem/Code='143'">
        <CVXmapping>
          <groups>
            <group>143</group>
            <group>82</group>
          </groups>
          <description>Adenovirus types 4 and 7</description>
        </CVXmapping>
      </xsl:when>
      <xsl:when test="OrderItem/Code='19'">
        <CVXmapping>
          <groups>
            <group>19</group>
          </groups>
          <description>BCG</description>
        </CVXmapping>
      </xsl:when>
      <xsl:when test="OrderItem/Code='28'">
        <CVXmapping>
          <groups>
            <group>28</group>
            <group>107</group>
          </groups>
          <description>DT (pediatric)</description>
        </CVXmapping>
      </xsl:when>
      <xsl:when test="OrderItem/Code='170'">
        <CVXmapping>
          <groups>
            <group>170</group>
            <group>89</group>
            <group>107</group>
            <group>17</group>
          </groups>
          <description>DTAP/IPV/HIB - non-US</description>
        </CVXmapping>
      </xsl:when>
      <xsl:when test="OrderItem/Code='01'">
        <CVXmapping>
          <groups>
            <group>01</group>
            <group>107</group>
          </groups>
          <description>DTP</description>
        </CVXmapping>
      </xsl:when>
      <xsl:when test="OrderItem/Code='22'">
        <CVXmapping>
          <groups>
            <group>22</group>
            <group>17</group>
            <group>107</group>
          </groups>
          <description>DTP-Hib</description>
        </CVXmapping>
      </xsl:when>
      <xsl:when test="OrderItem/Code='102'">
        <CVXmapping>
          <groups>
            <group>102</group>
            <group>17</group>
            <group>45</group>
            <group>107</group>
          </groups>
          <description>DTP-Hib-Hep B</description>
        </CVXmapping>
      </xsl:when>
      <xsl:when test="OrderItem/Code='20'">
        <CVXmapping>
          <groups>
            <group>20</group>
            <group>107</group>
          </groups>
          <description>DTaP</description>
        </CVXmapping>
      </xsl:when>
      <xsl:when test="OrderItem/Code='106'">
        <CVXmapping>
          <groups>
            <group>106</group>
            <group>107</group>
          </groups>
          <description>DTaP, 5 pertussis antigens</description>
        </CVXmapping>
      </xsl:when>
      <xsl:when test="OrderItem/Code='107'">
        <CVXmapping>
          <groups>
            <group>107</group>
          </groups>
          <description>DTaP, unspecified formulation</description>
        </CVXmapping>
      </xsl:when>
      <xsl:when test="OrderItem/Code='146'">
        <CVXmapping>
          <groups>
            <group>146</group>
            <group>17</group>
            <group>45</group>
            <group>89</group>
            <group>107</group>
          </groups>
          <description>DTaP,IPV,Hib,HepB</description>
        </CVXmapping>
      </xsl:when>
      <xsl:when test="OrderItem/Code='110'">
        <CVXmapping>
          <groups>
            <group>110</group>
            <group>45</group>
            <group>89</group>
            <group>107</group>
          </groups>
          <description>DTaP-Hep B-IPV</description>
        </CVXmapping>
      </xsl:when>
      <xsl:when test="OrderItem/Code='50'">
        <CVXmapping>
          <groups>
            <group>50</group>
            <group>17</group>
            <group>107</group>
          </groups>
          <description>DTaP-Hib</description>
        </CVXmapping>
      </xsl:when>
      <xsl:when test="OrderItem/Code='120'">
        <CVXmapping>
          <groups>
            <group>120</group>
            <group>89</group>
            <group>17</group>
            <group>107</group>
          </groups>
          <description>DTaP-Hib-IPV</description>
        </CVXmapping>
      </xsl:when>
      <xsl:when test="OrderItem/Code='130'">
        <CVXmapping>
          <groups>
            <group>130</group>
            <group>89</group>
            <group>107</group>
          </groups>
          <description>DTaP-IPV</description>
        </CVXmapping>
      </xsl:when>
      <xsl:when test="OrderItem/Code='132'">
        <CVXmapping>
          <groups>
            <group>132</group>
            <group>17</group>
            <group>107</group>
            <group>45</group>
            <group>89</group>
          </groups>
          <description>DTaP-IPV-HIB-HEP B, historical</description>
        </CVXmapping>
      </xsl:when>
      <xsl:when test="OrderItem/Code='118'">
        <CVXmapping>
          <groups>
            <group>118</group>
            <group>137</group>
          </groups>
          <description>HPV, bivalent</description>
        </CVXmapping>
      </xsl:when>
      <xsl:when test="OrderItem/Code='62'">
        <CVXmapping>
          <groups>
            <group>62</group>
            <group>137</group>
          </groups>
          <description>HPV, quadrivalent</description>
        </CVXmapping>
      </xsl:when>
      <xsl:when test="OrderItem/Code='137'">
        <CVXmapping>
          <groups>
            <group>137</group>
          </groups>
          <description>HPV, unspecified formulation</description>
        </CVXmapping>
      </xsl:when>
      <xsl:when test="OrderItem/Code='165'">
        <CVXmapping>
          <groups>
            <group>165</group>
            <group>137</group>
          </groups>
          <description>HPV9</description>
        </CVXmapping>
      </xsl:when>
      <xsl:when test="OrderItem/Code='52'">
        <CVXmapping>
          <groups>
            <group>52</group>
            <group>85</group>
          </groups>
          <description>Hep A, adult</description>
        </CVXmapping>
      </xsl:when>
      <xsl:when test="OrderItem/Code='83'">
        <CVXmapping>
          <groups>
            <group>83</group>
            <group>85</group>
          </groups>
          <description>Hep A, ped/adol, 2 dose</description>
        </CVXmapping>
      </xsl:when>
      <xsl:when test="OrderItem/Code='84'">
        <CVXmapping>
          <groups>
            <group>84</group>
            <group>85</group>
          </groups>
          <description>Hep A, ped/adol, 3 dose</description>
        </CVXmapping>
      </xsl:when>
      <xsl:when test="OrderItem/Code='31'">
        <CVXmapping>
          <groups>
            <group>31</group>
            <group>85</group>
          </groups>
          <description>Hep A, pediatric, unspecified formulation</description>
        </CVXmapping>
      </xsl:when>
      <xsl:when test="OrderItem/Code='85'">
        <CVXmapping>
          <groups>
            <group>85</group>
          </groups>
          <description>Hep A, unspecified formulation</description>
        </CVXmapping>
      </xsl:when>
      <xsl:when test="OrderItem/Code='104'">
        <CVXmapping>
          <groups>
            <group>104</group>
            <group>85</group>
            <group>45</group>
          </groups>
          <description>Hep A-Hep B</description>
        </CVXmapping>
      </xsl:when>
      <xsl:when test="OrderItem/Code='189'">
        <CVXmapping>
          <groups>
            <group>189</group>
            <group>45</group>
          </groups>
          <description>Hep B, adjuvanted</description>
        </CVXmapping>
      </xsl:when>
      <xsl:when test="OrderItem/Code='08'">
        <CVXmapping>
          <groups>
            <group>08</group>
            <group>45</group>
          </groups>
          <description>Hep B, adolescent or pediatric</description>
        </CVXmapping>
      </xsl:when>
      <xsl:when test="OrderItem/Code='42'">
        <CVXmapping>
          <groups>
            <group>42</group>
            <group>45</group>
          </groups>
          <description>Hep B, adolescent/high risk infant</description>
        </CVXmapping>
      </xsl:when>
      <xsl:when test="OrderItem/Code='43'">
        <CVXmapping>
          <groups>
            <group>43</group>
            <group>45</group>
          </groups>
          <description>Hep A, adult</description>
        </CVXmapping>
      </xsl:when>
      <xsl:when test="OrderItem/Code='44'">
        <CVXmapping>
          <groups>
            <group>44</group>
            <group>45</group>
          </groups>
          <description>Hep B, dialysis</description>
        </CVXmapping>
      </xsl:when>
      <xsl:when test="OrderItem/Code='45'">
        <CVXmapping>
          <groups>
            <group>45</group>
          </groups>
          <description>Hep B, unspecified formulation</description>
        </CVXmapping>
      </xsl:when>
      <xsl:when test="OrderItem/Code='58'">
        <CVXmapping>
          <groups>
            <group>58</group>
          </groups>
          <description>Hep C</description>
        </CVXmapping>
      </xsl:when>
      <xsl:when test="OrderItem/Code='59'">
        <CVXmapping>
          <groups>
            <group>59</group>
          </groups>
          <description>Hep E</description>
        </CVXmapping>
      </xsl:when>
      <xsl:when test="OrderItem/Code='47'">
        <CVXmapping>
          <groups>
            <group>47</group>
            <group>17</group>
          </groups>
          <description>Hib (HbOC)</description>
        </CVXmapping>
      </xsl:when>
      <xsl:when test="OrderItem/Code='46'">
        <CVXmapping>
          <groups>
            <group>46</group>
            <group>17</group>
          </groups>
          <description>Hib (PRP-D)</description>
        </CVXmapping>
      </xsl:when>
      <xsl:when test="OrderItem/Code='49'">
        <CVXmapping>
          <groups>
            <group>49</group>
            <group>17</group>
          </groups>
          <description>Hib (PRP-OMP)</description>
        </CVXmapping>
      </xsl:when>
      <xsl:when test="OrderItem/Code='48'">
        <CVXmapping>
          <groups>
            <group>48</group>
            <group>17</group>
          </groups>
          <description>Hib (PRP-T)</description>
        </CVXmapping>
      </xsl:when>
      <xsl:when test="OrderItem/Code='17'">
        <CVXmapping>
          <groups>
            <group>17</group>
          </groups>
          <description>Hib, unspecified formulation</description>
        </CVXmapping>
      </xsl:when>
      <xsl:when test="OrderItem/Code='51'">
        <CVXmapping>
          <groups>
            <group>51</group>
            <group>17</group>
            <group>45</group>
          </groups>
          <description>Hib-Hep B</description>
        </CVXmapping>
      </xsl:when>
      <xsl:when test="OrderItem/Code='10'">
        <CVXmapping>
          <groups>
            <group>10</group>
            <group>89</group>
          </groups>
          <description>IPV</description>
        </CVXmapping>
      </xsl:when>
      <xsl:when test="OrderItem/Code='160'">
        <CVXmapping>
          <groups>
            <group>160</group>
            <group>123</group>
          </groups>
          <description>Influenza A monovalent (H5N1), ADJUVANTED-2013</description>
        </CVXmapping>
      </xsl:when>
      <xsl:when test="OrderItem/Code='153'">
        <CVXmapping>
          <groups>
            <group>153</group>
            <group>88</group>
          </groups>
          <description>Influenza, injectable, MDCK, preservative free</description>
        </CVXmapping>
      </xsl:when>
      <xsl:when test="OrderItem/Code='171'">
        <CVXmapping>
          <groups>
            <group>171</group>
            <group>88</group>
          </groups>
          <description>Influenza, injectable, MDCK, preservative free, quadrivalent</description>
        </CVXmapping>
      </xsl:when>
      <xsl:when test="OrderItem/Code='186'">
        <CVXmapping>
          <groups>
            <group>186</group>
            <group>88</group>
          </groups>
          <description>Influenza, injectable, MDCK, quadrivalent, preservative</description>
        </CVXmapping>
      </xsl:when>
      <xsl:when test="OrderItem/Code='161'">
        <CVXmapping>
          <groups>
            <group>161</group>
            <group>88</group>
          </groups>
          <description>Influenza, injectable, quadrivalent, preservative free, pediatric</description>
        </CVXmapping>
      </xsl:when>
      <xsl:when test="OrderItem/Code='141'">
        <CVXmapping>
          <groups>
            <group>141</group>
            <group>88</group>
          </groups>
          <description>Influenza, seasonal, injectable</description>
        </CVXmapping>
      </xsl:when>
      <xsl:when test="OrderItem/Code='135'">
        <CVXmapping>
          <groups>
            <group>135</group>
            <group>88</group>
          </groups>
          <description>Influenza, high dose seasonal</description>
        </CVXmapping>
      </xsl:when>
      <xsl:when test="OrderItem/Code='140'">
        <CVXmapping>
          <groups>
            <group>140</group>
            <group>88</group>
          </groups>
          <description>Influenza, seasonal, injectable, preservative free</description>
        </CVXmapping>
      </xsl:when>
      <xsl:when test="OrderItem/Code='134'">
        <CVXmapping>
          <groups>
            <group>134</group>
            <group>129</group>
          </groups>
          <description>Japanese Encephalitis IM</description>
        </CVXmapping>
      </xsl:when>
      <xsl:when test="OrderItem/Code='129'">
        <CVXmapping>
          <groups>
            <group>129</group>
          </groups>
          <description>Japanese Encephalitis, unspecified formulation</description>
        </CVXmapping>
      </xsl:when>
      <xsl:when test="OrderItem/Code='39'">
        <CVXmapping>
          <groups>
            <group>39</group>
            <group>129</group>
          </groups>
          <description>Japanese encephalitis SC</description>
        </CVXmapping>
      </xsl:when>
      <xsl:when test="OrderItem/Code='66'">
        <CVXmapping>
          <groups>
            <group>66</group>
          </groups>
          <description>Lyme disease</description>
        </CVXmapping>
      </xsl:when>
      <xsl:when test="OrderItem/Code='04'">
        <CVXmapping>
          <groups>
            <group>04</group>
            <group>03</group>
          </groups>
          <description>M/R</description>
        </CVXmapping>
      </xsl:when>
      <xsl:when test="OrderItem/Code='03'">
        <CVXmapping>
          <groups>
            <group>03</group>
          </groups>
          <description>MMR</description>
        </CVXmapping>
      </xsl:when>
      <xsl:when test="OrderItem/Code='94'">
        <CVXmapping>
          <groups>
            <group>94</group>
            <group>21</group>
            <group>03</group>
          </groups>
          <description>MMRV</description>
        </CVXmapping>
      </xsl:when>
      <xsl:when test="OrderItem/Code='148'">
        <CVXmapping>
          <groups>
            <group>148</group>
            <group>17</group>
            <group>108</group>
          </groups>
          <description>Meningococcal C/Y-HIB PRP</description>
        </CVXmapping>
      </xsl:when>
      <xsl:when test="OrderItem/Code='136'">
        <CVXmapping>
          <groups>
            <group>136</group>
            <group>108</group>
          </groups>
          <description>Meningococcal MCV40</description>
        </CVXmapping>
      </xsl:when>
      <xsl:when test="OrderItem/Code='127'">
        <CVXmapping>
          <groups>
            <group>127</group>
            <group>128</group>
          </groups>
          <description>Novel Influenza-H1N1-09</description>
        </CVXmapping>
      </xsl:when>
      <xsl:when test="OrderItem/Code='128'">
        <CVXmapping>
          <groups>
            <group>128</group>
          </groups>
          <description>Novel Influenza-H1N1-09, all formulations</description>
        </CVXmapping>
      </xsl:when>
      <xsl:when test="OrderItem/Code='125'">
        <CVXmapping>
          <groups>
            <group>125</group>
            <group>128</group>
          </groups>
          <description>Novel Influenza-H1N1-09, nasal</description>
        </CVXmapping>
      </xsl:when>
      <xsl:when test="OrderItem/Code='126'">
        <CVXmapping>
          <groups>
            <group>126</group>
            <group>128</group>
          </groups>
          <description>Novel Influenza-H1N1-09, preservative free</description>
        </CVXmapping>
      </xsl:when>
      <xsl:when test="OrderItem/Code='02'">
        <CVXmapping>
          <groups>
            <group>02</group>
            <group>89</group>
          </groups>
          <description>OPV</description>
        </CVXmapping>
      </xsl:when>
      <xsl:when test="OrderItem/Code='177'">
        <CVXmapping>
          <groups>
            <group>177</group>
            <group>152</group>
          </groups>
          <description>PCV10</description>
        </CVXmapping>
      </xsl:when>
      <xsl:when test="OrderItem/Code='152'">
        <CVXmapping>
          <groups>
            <group>152</group>
          </groups>
          <description>Pneuomococcal Conjugate, unspecified formulation</description>
        </CVXmapping>
      </xsl:when>
      <xsl:when test="OrderItem/Code='133'">
        <CVXmapping>
          <groups>
            <group>133</group>
            <group>152</group>
          </groups>
          <description>Pneuomococcal conjugate PCV 13</description>
        </CVXmapping>
      </xsl:when>
      <xsl:when test="OrderItem/Code='175'">
        <CVXmapping>
          <groups>
            <group>175</group>
            <group>90</group>
          </groups>
          <description>Rabies - IM Diploid cell culture</description>
        </CVXmapping>
      </xsl:when>
      <xsl:when test="OrderItem/Code='176'">
        <CVXmapping>
          <groups>
            <group>176</group>
            <group>90</group>
          </groups>
          <description>Rabies - IM fibroblast culture</description>
        </CVXmapping>
      </xsl:when>
      <xsl:when test="OrderItem/Code='138'">
        <CVXmapping>
          <groups>
            <group>138</group>
            <group>139</group>
          </groups>
          <description>Td (adult)</description>
        </CVXmapping>
      </xsl:when>
      <xsl:when test="OrderItem/Code='139'">
        <CVXmapping>
          <groups>
            <group>139</group>
          </groups>
          <description>Td (adult) unspecified formulation</description>
        </CVXmapping>
      </xsl:when>
      <xsl:when test="OrderItem/Code='113'">
        <CVXmapping>
          <groups>
            <group>113</group>
            <group>139</group>
          </groups>
          <description>Td (adult), 5 Lf tetanus toxoid, preservative free, absorbed</description>
        </CVXmapping>
      </xsl:when>
      <xsl:when test="OrderItem/Code='09'">
        <CVXmapping>
          <groups>
            <group>09</group>
            <group>139</group>
          </groups>
          <description>Td (adult), 2 Lf tetanus toxoid, preservative free, absorbed</description>
        </CVXmapping>
      </xsl:when>
      <xsl:when test="OrderItem/Code='115'">
        <CVXmapping>
          <groups>
            <group>115</group>
          </groups>
          <description>Tdap</description>
        </CVXmapping>
      </xsl:when>
      <xsl:when test="OrderItem/Code='81'">
        <CVXmapping>
          <groups>
            <group>81</group>
            <group>92</group>
          </groups>
          <description>VEE, inactivated</description>
        </CVXmapping>
      </xsl:when>
      <xsl:when test="OrderItem/Code='80'">
        <CVXmapping>
          <groups>
            <group>80</group>
            <group>92</group>
          </groups>
          <description>VEE, live</description>
        </CVXmapping>
      </xsl:when>
      <xsl:when test="OrderItem/Code='92'">
        <CVXmapping>
          <groups>
            <group>92</group>
          </groups>
          <description>VEE, unspecified formulation</description>
        </CVXmapping>
      </xsl:when>
      <xsl:when test="OrderItem/Code='183'">
        <CVXmapping>
          <groups>
            <group>183</group>
            <group>184</group>
          </groups>
          <description>Yellow fever vaccine - alt</description>
        </CVXmapping>
      </xsl:when>
      <xsl:when test="OrderItem/Code='184'">
        <CVXmapping>
          <groups>
            <group>184</group>
          </groups>
          <description>Yellow fever, unspecified formulation</description>
        </CVXmapping>
      </xsl:when>
      <xsl:when test="OrderItem/Code='54'">
        <CVXmapping>
          <groups>
            <group>54</group>
            <group>82</group>
          </groups>
          <description>adenovirus, type 4</description>
        </CVXmapping>
      </xsl:when>
      <xsl:when test="OrderItem/Code='55'">
        <CVXmapping>
          <groups>
            <group>55</group>
            <group>82</group>
          </groups>
          <description>adenovirus, type 7</description>
        </CVXmapping>
      </xsl:when>
      <xsl:when test="OrderItem/Code='82'">
        <CVXmapping>
          <groups>
            <group>82</group>
          </groups>
          <description>adenovirus, unspecified formulation</description>
        </CVXmapping>
      </xsl:when>
      <xsl:when test="OrderItem/Code='24'">
        <CVXmapping>
          <groups>
            <group>24</group>
          </groups>
          <description>anthrax</description>
        </CVXmapping>
      </xsl:when>
      <xsl:when test="OrderItem/Code='173'">
        <CVXmapping>
          <groups>
            <group>173</group>
            <group>26</group>
          </groups>
          <description>cholera, BivWC</description>
        </CVXmapping>
      </xsl:when>
      <xsl:when test="OrderItem/Code='172'">
        <CVXmapping>
          <groups>
            <group>172</group>
            <group>26</group>
          </groups>
          <description>cholera, WC-rBS</description>
        </CVXmapping>
      </xsl:when>
      <xsl:when test="OrderItem/Code='174'">
        <CVXmapping>
          <groups>
            <group>174</group>
            <group>26</group>
          </groups>
          <description>cholera, live attenuated</description>
        </CVXmapping>
      </xsl:when>
      <xsl:when test="OrderItem/Code='26'">
        <CVXmapping>
          <groups>
            <group>26</group>
          </groups>
          <description>cholera, unspecified formulation</description>
        </CVXmapping>
      </xsl:when>
      <xsl:when test="OrderItem/Code='151'">
        <CVXmapping>
          <groups>
            <group>151</group>
            <group>88</group>
          </groups>
          <description>influenza nasal, unspecified formulation</description>
        </CVXmapping>
      </xsl:when>
      <xsl:when test="OrderItem/Code='123'">
        <CVXmapping>
          <groups>
            <group>123</group>
          </groups>
          <description>influenza, H5N1-1203</description>
        </CVXmapping>
      </xsl:when>
      <xsl:when test="OrderItem/Code='158'">
        <CVXmapping>
          <groups>
            <group>158</group>
            <group>88</group>
          </groups>
          <description>influenza, injectable, quadrivalent</description>
        </CVXmapping>
      </xsl:when>
      <xsl:when test="OrderItem/Code='150'">
        <CVXmapping>
          <groups>
            <group>150</group>
            <group>88</group>
          </groups>
          <description>influenza, injectable, quadrivalent, preservative free</description>
        </CVXmapping>
      </xsl:when>
      <xsl:when test="OrderItem/Code='166'">
        <CVXmapping>
          <groups>
            <group>166</group>
            <group>88</group>
          </groups>
          <description>influenza, intradermal, quadrivalent, preservative free</description>
        </CVXmapping>
      </xsl:when>
      <xsl:when test="OrderItem/Code='111'">
        <CVXmapping>
          <groups>
            <group>111</group>
            <group>88</group>
          </groups>
          <description>influenza, live, intranasal</description>
        </CVXmapping>
      </xsl:when>
      <xsl:when test="OrderItem/Code='149'">
        <CVXmapping>
          <groups>
            <group>149</group>
            <group>88</group>
          </groups>
          <description>influenza, live, intranasal, quadrivalent</description>
        </CVXmapping>
      </xsl:when>
      <xsl:when test="OrderItem/Code='155'">
        <CVXmapping>
          <groups>
            <group>155</group>
            <group>88</group>
          </groups>
          <description>influenza, recombinant, injectable, preservative free</description>
        </CVXmapping>
      </xsl:when>
      <xsl:when test="OrderItem/Code='185'">
        <CVXmapping>
          <groups>
            <group>185</group>
            <group>88</group>
          </groups>
          <description>influenza, recombinant, quadrivalent, injectable, preservative free</description>
        </CVXmapping>
      </xsl:when>
      <xsl:when test="OrderItem/Code='15'">
        <CVXmapping>
          <groups>
            <group>15</group>
            <group>88</group>
          </groups>
          <description>influenza, unspecified formulation</description>
        </CVXmapping>
      </xsl:when>
      <xsl:when test="OrderItem/Code='168'">
        <CVXmapping>
          <groups>
            <group>168</group>
            <group>88</group>
          </groups>
          <description>influenza, trivalent, adjuvanted</description>
        </CVXmapping>
      </xsl:when>
      <xsl:when test="OrderItem/Code='88'">
        <CVXmapping>
          <groups>
            <group>88</group>
          </groups>
          <description>influenza, unspecified formulation</description>
        </CVXmapping>
      </xsl:when>
      <xsl:when test="OrderItem/Code='144'">
        <CVXmapping>
          <groups>
            <group>144</group>
            <group>88</group>
          </groups>
          <description>influenza, seasonal, intradermal, preservative free</description>
        </CVXmapping>
      </xsl:when>
      <xsl:when test="OrderItem/Code='16'">
        <CVXmapping>
          <groups>
            <group>16</group>
            <group>88</group>
          </groups>
          <description>influenza, whole</description>
        </CVXmapping>
      </xsl:when>
      <xsl:when test="OrderItem/Code='05'">
        <CVXmapping>
          <groups>
            <group>05</group>
            <group>03</group>
          </groups>
          <description>measles</description>
        </CVXmapping>
      </xsl:when>
      <xsl:when test="OrderItem/Code='108'">
        <CVXmapping>
          <groups>
            <group>108</group>
          </groups>
          <description>meningococcal ACWY, unspecified formulation</description>
        </CVXmapping>
      </xsl:when>
      <xsl:when test="OrderItem/Code='163'">
        <CVXmapping>
          <groups>
            <group>163</group>
            <group>164</group>
          </groups>
          <description>meningococcal B, OMV</description>
        </CVXmapping>
      </xsl:when>
      <xsl:when test="OrderItem/Code='162'">
        <CVXmapping>
          <groups>
            <group>162</group>
            <group>164</group>
          </groups>
          <description>meningococcal B, recombinant</description>
        </CVXmapping>
      </xsl:when>
      <xsl:when test="OrderItem/Code='164'">
        <CVXmapping>
          <groups>
            <group>164</group>
          </groups>
          <description>meningococcal B, unspecified</description>
        </CVXmapping>
      </xsl:when>
      <xsl:when test="OrderItem/Code='103'">
        <CVXmapping>
          <groups>
            <group>103</group>
            <group>108</group>
          </groups>
          <description>meningococcal C, conjugate</description>
        </CVXmapping>
      </xsl:when>
      <xsl:when test="OrderItem/Code='147'">
        <CVXmapping>
          <groups>
            <group>147</group>
            <group>108</group>
          </groups>
          <description>meningococcal MCV4, unspecified formulation</description>
        </CVXmapping>
      </xsl:when>
      <xsl:when test="OrderItem/Code='114'">
        <CVXmapping>
          <groups>
            <group>114</group>
            <group>108</group>
          </groups>
          <description>meningococcal MCV4P</description>
        </CVXmapping>
      </xsl:when>
      <xsl:when test="OrderItem/Code='32'">
        <CVXmapping>
          <groups>
            <group>32</group>
            <group>108</group>
          </groups>
          <description>meningococcal MPSV4</description>
        </CVXmapping>
      </xsl:when>
      <xsl:when test="OrderItem/Code='07'">
        <CVXmapping>
          <groups>
            <group>07</group>
            <group>03</group>
          </groups>
          <description>mumps</description>
        </CVXmapping>
      </xsl:when>
      <xsl:when test="OrderItem/Code='23'">
        <CVXmapping>
          <groups>
            <group>23</group>
          </groups>
          <description>plague</description>
        </CVXmapping>
      </xsl:when>
      <xsl:when test="OrderItem/Code='100'">
        <CVXmapping>
          <groups>
            <group>100</group>
            <group>152</group>
          </groups>
          <description>pneumococcal conjugate PCV 7</description>
        </CVXmapping>
      </xsl:when>
      <xsl:when test="OrderItem/Code='33'">
        <CVXmapping>
          <groups>
            <group>33</group>
          </groups>
          <description>pneumococcal polysaccharide PPV23</description>
        </CVXmapping>
      </xsl:when>
      <xsl:when test="OrderItem/Code='89'">
        <CVXmapping>
          <groups>
            <group>89</group>
          </groups>
          <description>polio, unspecified formulation</description>
        </CVXmapping>
      </xsl:when>
      <xsl:when test="OrderItem/Code='40'">
        <CVXmapping>
          <groups>
            <group>40</group>
            <group>90</group>
          </groups>
          <description>rabies, intradermal injection</description>
        </CVXmapping>
      </xsl:when>
      <xsl:when test="OrderItem/Code='18'">
        <CVXmapping>
          <groups>
            <group>18</group>
            <group>90</group>
          </groups>
          <description>rabies, intramuscular injection</description>
        </CVXmapping>
      </xsl:when>
      <xsl:when test="OrderItem/Code='90'">
        <CVXmapping>
          <groups>
            <group>90</group>
          </groups>
          <description>rabies, unspecified formulation</description>
        </CVXmapping>
      </xsl:when>
      <xsl:when test="OrderItem/Code='119'">
        <CVXmapping>
          <groups>
            <group>119</group>
            <group>122</group>
          </groups>
          <description>rotavirus, monovalent</description>
        </CVXmapping>
      </xsl:when>
      <xsl:when test="OrderItem/Code='116'">
        <CVXmapping>
          <groups>
            <group>116</group>
            <group>122</group>
          </groups>
          <description>rotavirus, pentavalent</description>
        </CVXmapping>
      </xsl:when>
      <xsl:when test="OrderItem/Code='74'">
        <CVXmapping>
          <groups>
            <group>74</group>
            <group>122</group>
          </groups>
          <description>rotavirus, tetravalent</description>
        </CVXmapping>
      </xsl:when>
      <xsl:when test="OrderItem/Code='122'">
        <CVXmapping>
          <groups>
            <group>122</group>
          </groups>
          <description>rotavirus, unspecified formulation</description>
        </CVXmapping>
      </xsl:when>
      <xsl:when test="OrderItem/Code='06'">
        <CVXmapping>
          <groups>
            <group>06</group>
            <group>03</group>
          </groups>
          <description>rubella</description>
        </CVXmapping>
      </xsl:when>
      <xsl:when test="OrderItem/Code='38'">
        <CVXmapping>
          <groups>
            <group>38</group>
            <group>03</group>
          </groups>
          <description>rubella/mumps</description>
        </CVXmapping>
      </xsl:when>
      <xsl:when test="OrderItem/Code='101'">
        <CVXmapping>
          <groups>
            <group>101</group>
            <group>91</group>
          </groups>
          <description>typhoid, ViCPs</description>
        </CVXmapping>
      </xsl:when>
      <xsl:when test="OrderItem/Code='25'">
        <CVXmapping>
          <groups>
            <group>25</group>
            <group>91</group>
          </groups>
          <description>typhoid, oral</description>
        </CVXmapping>
      </xsl:when>
      <xsl:when test="OrderItem/Code='41'">
        <CVXmapping>
          <groups>
            <group>41</group>
            <group>91</group>
          </groups>
          <description>typhoid, parenteral</description>
        </CVXmapping>
      </xsl:when>
      <xsl:when test="OrderItem/Code='53'">
        <CVXmapping>
          <groups>
            <group>53</group>
            <group>91</group>
          </groups>
          <description>typhoid, parenteral, AKD (U.S. military)</description>
        </CVXmapping>
      </xsl:when>
      <xsl:when test="OrderItem/Code='91'">
        <CVXmapping>
          <groups>
            <group>91</group>
          </groups>
          <description>typhoid, unspecified formulation</description>
        </CVXmapping>
      </xsl:when>
      <xsl:when test="OrderItem/Code='75'">
        <CVXmapping>
          <groups>
            <group>75</group>
          </groups>
          <description>vaccinia (smallpox)</description>
        </CVXmapping>
      </xsl:when>
      <xsl:when test="OrderItem/Code='105'">
        <CVXmapping>
          <groups>
            <group>105</group>
            <group>75</group>
          </groups>
          <description>vaccinia (smallpox) diluted</description>
        </CVXmapping>
      </xsl:when>
      <xsl:when test="OrderItem/Code='21'">
        <CVXmapping>
          <groups>
            <group>21</group>
          </groups>
          <description>varicella</description>
        </CVXmapping>
      </xsl:when>
      <xsl:when test="OrderItem/Code='37'">
        <CVXmapping>
          <groups>
            <group>37</group>
            <group>184</group>
          </groups>
          <description>yellow fever</description>
        </CVXmapping>
      </xsl:when>
      <xsl:when test="OrderItem/Code='121'">
        <CVXmapping>
          <groups>
            <group>121</group>
            <group>188</group>
          </groups>
          <description>zoster live</description>
        </CVXmapping>
      </xsl:when>
      <xsl:when test="OrderItem/Code='187'">
        <CVXmapping>
          <groups>
            <group>187</group>
            <group>188</group>
          </groups>
          <description>zoster subunit</description>
        </CVXmapping>
      </xsl:when>
      <xsl:when test="OrderItem/Code='188'">
        <CVXmapping>
          <groups>
            <group>188</group>
          </groups>
          <description>zoster, unspecified formulation</description>
        </CVXmapping>
      </xsl:when>
    </xsl:choose>
  </xsl:template>
</xsl:stylesheet>
