# VDIF

## Getting Started

The provided Vagrantfile sets up a VDIF developer runtime environment. The resulting VM is based on dvazquez/HealthShare2017 which contains a HealthShare 2017.1 installation on CentOS 7.  The Vagrantfile further provisions the VM and HS installation by installing VDIF custom classes and by creating HSREGISTRY, HSREPOSITORY (Edge Gateway), HSEDGCHY (Edge Gateway), HSEDGDAYT (Edge Gateway) and HSACCCDA (Access Gateway for on-dement CDA document generation) productions.

A license key (cache.key) is required to use the Information Exchange and/or HealthConnect functionality.  The provisioning script will copy cache.key from <VDIF_WORKING_DIRECTORY>/.vagrant/Software if present.  You will have to manually import the key if it's not available when the VM is provisioned.  You can import the key using the Management Console or by copying it to /opt/HS/mgr (the file must be named cache.key).

### Prerequisites

#### Windows 7

* Latest version of Oracle VirtualBox ([https://www.oracle.com/technetwork/server-storage/virtualbox/downloads/index.html](https://www.oracle.com/technetwork/server-storage/virtualbox/downloads/index.html)).
* Latest version of HashiCorp Vagrant ([https://www.vagrantup.com/](https://www.vagrantup.com/)).
* Install vagrant-vbguest plugin.  This plugin enables file sharing of directories on the Windows host with the VM. Provisioning will not succeed if this plugin is not installed. Use the following command to install the plugin:

```bash
vagrant plugin install vagrant-vbguest
```

#### Windows 10

* Hyper-V must be installed (Programs and Features | Turn Windows Features on or off). 
* Latest version of HashiCorp Vagrant ([https://www.vagrantup.com/](https://www.vagrantup.com/)).

#### Common

* Install vagrant-timezone plugin.  This plugin will set the timezone of the VM to match the timezone of the host operating system.  The VM provisioning will gracefully handle this plugin not being installed; however, your VM's timezone will be UTC.  Use this command to install the plugin:

```bash
vagrant plugin install vagrant-timezone
```

### Starting up the VM

#### General

The following environment variables can be used to custom tailor the VM to your needs. Set them with a script (.bat or .sh) before issuing the vagrant up command.

| Name              | Description                                      | Default |
| ----------------- | ------------------------------------------------ | ------- |
| CSP_PORT          | Mangement Console port.                          | 57772   |
| SUPER_USER_PORT   | Cache Super User Port for use by Studio.         | 1972    |
| VAGRANT_USER*     | Username of Windows user that can create shares. |         |
| VAGRANT_PASSWORD* | Password of Windows user that can create shares. |         |

\* - Only used with Windows 10 and hyperv provider.

#### Windows 7

1. Launch git-bash terminal.  CMD might work too if your Windows PATH includes the git commands, but things work alot more smoothly in git-bash.
2. Change directory to where you cloned the VDIF git repository.
3. Run this command:

```bash
vagrant up
```

VirtualBox and vagrant will set up the VM with a NATed network configuration.  This configuration will allow you to access the VM via localhost, but will also require you to configure port forwarding rules if you add listners beyond the ones in Vagrantfile.  The VM is configured to forward the port specified in CSP_PORT to 57772 in the guest and SUPER_USER_PORT to 1972 in the guest.

#### Windows 10

1. Launch git-bash terminal as Administrator.  CMD or PowerShell might work too if your Windows PATH includes the git commands, but things work alot more smoothly in git-bash.
2. The Vagrant hyper-v provider uses SMB to share files in the host filesystme with the guest OS.  In order for the share to work, a username and password must be provided.  See the **General** section above.
3. Run this command:

```bash
vagrant up --provider hyperv
```

4. Select the appropriate network switch from the list when prompted.  The Default network switch will suffice for most uses so the VM will have a 172.x.x.x network address that is only reachable from the host on which it is running.  You also have the option to create an External network switch and selecting it here if you want the VM to be reachable from other machines on the network.
5.  Enter the username and password of the user that has privileges to create shares on the host machine when prompted.  The input should match the values used for VAGRANT_USER and VAGRANT_PASSWORD.
6.  Wait for the provisioning to complete.

The IP address from which the VM is accessible will depend on whether you picked an Internal or External switch when creating the VM.  You can use the Hyper-V Manager to determine the IP address.  NATed configurations are currently not supported with the Hyper-V provider so you will not be able to access the VM using localhost nor will you have to worry about forwarding ports.

### Post installation

After the VM is created, log in to the Management Portal (see **Accessing HealthShare and the VM** below) and perform the following steps:

1. Go to HealthShare Installer Wizard and click Edit on the HSACCCDA row.  Ensure that the value in the Enter a Hub Name field is HSREGISTRY.
2. Repeat step 1 for HSEDGCHY and HSEDGDAYT.
3. Use Stop All and Start All buttons to restart all of the productions.
4. In Management Portal, go to HSREGISTRY | Delivery Management | Receiving Systems. Click on the line with *Default* in the Name column. Click the *Delivery Policies* tab. Click the *Register OnDemand* row. Select *vdif-ep:HSACCCDA* using the drop-down in the Access Gateway field. Click *Save Policy*.
5. Go to System Administration | Configuration | System Configuration | Namespaces.  For HSREGISTRY, HSACCCDA, HSCHYSHR, HSEDGDAYT and HSREPOSITORY; click the *Package Mappings* link.  Ensure that mappings exist for Custom->HSCUSTOM and HS.Local->HSCUSTOM.
6. **OPTIONAL** - To use external VA MVI functionality provided by VA.MVI (HS.Local.VA.HS.Registry.MVI... classes), set the MPIOperations property of the HS.Hub.MPI.Manager component in HSREGISTRY to *VA.MVI.Operations*. Connectivity to MVI is configured in the Service Registry under *MVI.PDQv3.Consumer*.  This Service Registry entry points to a mock MVI service hosted on MOCK-HOST:8082.  The mock MVI implementation can be found in Testing/SoapUIMocks/MockMVIService-soapui-project.xml.  Add an entry to /etc/hosts in the VM for MOCK-HOST that points to the IP address of the machine where you're running SoapUI (this will usually be the same host in which the VM is running).
7. Copy data to the edges:

```
vagrant ssh
cp /hs/SampleData/NWHIN*CHYSHR.xml /opt/HS/Data/HSEDGCHY/SDAIn
cp /hs/SampleData/NWHIN*DAYTSHR.xml /opt/HS/Data/HSEDGDAYT/SDAIn
```

1. View message traces on HSEDGCHY and HSEDGDAYT to ensure the data was succesfully loaded.

### Accessing HealthShare and the VM

The VM can be accessed using SSH or via a web browser.

#### HealthShare

Access HealthShare's Management Console using http://<ip_address_of_vm>:<CSP_PORT>/csp/sys/UtilHome.csp. Install the HealthShare Client on the host machine and set the Preferred Server to the VM's IP to make this process easier.  Installing the Client tools will also make it possible to connect to the VM using Cache Studio.  Terminal will not work because it uses Telnet protocol which is not installed in the VM.

The HealthShare installation has all of the standard users (_SYSTEM, Admin, CSPSystem, etc.).  There is also a user named **cacheusr** at both the OS and Cache levels to serve as the database owner.  The password of all of the accounts is *root*.

#### SSH

Use SSH to connect to the VM to run csession (Terminal).  Change directory to the VDIF working directory and execute the following command:

```bash
vagrant ssh
```

You will be logged in as a user named **vagrant** which can perform the same functions as **cacheusr** (e. g. start/stop Cache).

### Updating the VM

VDIF-EP is a work in progress; therefore, it will be necessary at times to reset the HealthShare productions that it uses. These updates can come in various forms and can be something as minor as a change to a class to major changes like adding a new production.  Destroying and rebuilding the vagrant box whenever this happens takes alot of time. To reset your VM's VDIF-EP HealthConfiguration do the following:

1. Start the VM.
2. Connect to the VM using SSH.
3. Run the following command.

```bash
/hs/vagrant-scripts/reset-vdif.sh
```

4. Perform the steps in Post Installation section.

### Considerations

Cache is started as using run.sh to run the cstart command.  Therefore, it will not be shutdown when the VM is shutdown.  If you want to minimize the risk is corrupting the Cache database, SSH into the VM and run cstop before shutting down the VM.
